==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/tr.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kişiler",
    "Address book name" : "Adres defteri adı",
    "Import" : "İçe aktar",
    "The selected image is too big (max 1MB)" : "Seçilen resim çok büyük (azami 1MB)",
    "No contacts in here" : "Burada kişi yok",
    "Name" : "Ad",
    "Organization" : "Kurum",
    "Title" : "Başlık",
    "Add field ..." : "Alan ekle...",
    "+ New contact" : "Yeni Kişi",
    "No search result for {query}" : "{query} için arama sonucu yok",
    "_%n contact_::_%n contacts_" : ["%n kişi","%n kişi"],
    "Post office box" : "Posta kutusu",
    "Postal code" : "Posta kodu",
    "City" : "Şehir",
    "State or province" : "Eyalet",
    "Country" : "Ülke",
    "Address" : "Adres",
    "(new group)" : "(yeni grup)",
    "Last name" : "Soyad",
    "First name" : "Ad",
    "Additional names" : "İlave isimler",
    "Prefix" : "Önek",
    "Suffix" : "Sonek",
    "All contacts" : "Tüm kişiler",
    "Not grouped" : "Gruplanmamış",
    "New contact" : "Yeni kişi",
    "{addressbook} shared by {owner}" : "{owner} tarafından paylaşılmış {addressbook}",
    "No contacts in file. Only VCard files are allowed." : "Dosyada kişi yok. Sadece vCard dosyalarına izin verilir.",
    "Nickname" : "Takma ad",
    "Detailed name" : "Ayrıntılı isim",
    "Notes" : "Notlar",
    "Website" : "Web sitesi",
    "Federated Cloud ID" : "Birleşmiş Bulut Kimliği",
    "Home" : "Ev",
    "Work" : "İş",
    "Other" : "Diğer",
    "Groups" : "Gruplar",
    "Birthday" : "Doğum günü",
    "Anniversary" : "Yıl Dönümü",
    "Date of death" : "Ölüm Tarihi",
    "Email" : "E-posta",
    "Instant messaging" : "Anında mesajlaşma",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Faks",
    "Fax home" : "Ev faks",
    "Fax work" : "İş faks",
    "Pager" : "Çağrı Cihazı",
    "Voice" : "Ses",
    "Social network" : "Sosyal ağ",
    "Settings" : "Ayarlar"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/tr.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kişiler",
    "Download" : "İndir",
    "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
    "Delete" : "Sil",
    "can edit" : "düzenleyebilir",
    "Address book name" : "Adres defteri adı",
    "Import" : "İçe aktar",
    "The selected image is too big (max 1MB)" : "Seçilen resim çok büyük (azami 1MB)",
    "No contacts in here" : "Burada kişi yok",
    "Name" : "Ad",
    "Organization" : "Kurum",
    "Title" : "Başlık",
    "Add field ..." : "Alan ekle...",
    "No search result for {query}" : "{query} için arama sonucu yok",
    "_%n contact_::_%n contacts_" : ["%n kişi","%n kişi"],
    "Post office box" : "Posta kutusu",
    "Postal code" : "Posta kodu",
    "City" : "Şehir",
    "State or province" : "Eyalet",
    "Country" : "Ülke",
    "Address" : "Adres",
    "(new group)" : "(yeni grup)",
    "Last name" : "Soyad",
    "First name" : "Ad",
    "Additional names" : "İlave isimler",
    "Prefix" : "Önek",
    "Suffix" : "Sonek",
    "All contacts" : "Tüm kişiler",
    "Not grouped" : "Gruplanmamış",
    "New contact" : "Yeni kişi",
    "{addressbook} shared by {owner}" : "{owner} tarafından paylaşılmış {addressbook}",
    "No contacts in file. Only VCard files are allowed." : "Dosyada kişi yok. Sadece vCard dosyalarına izin verilir.",
    "Nickname" : "Takma ad",
    "Detailed name" : "Ayrıntılı isim",
    "Notes" : "Notlar",
    "Website" : "Web sitesi",
    "Federated Cloud ID" : "Birleşmiş Bulut Kimliği",
    "Home" : "Ev",
    "Work" : "İş",
    "Other" : "Diğer",
    "Groups" : "Gruplar",
    "Birthday" : "Doğum günü",
    "Anniversary" : "Yıl Dönümü",
    "Date of death" : "Ölüm Tarihi",
    "Email" : "E-posta",
    "Instant messaging" : "Anında mesajlaşma",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Faks",
    "Fax home" : "Ev faks",
    "Fax work" : "İş faks",
    "Pager" : "Çağrı Cihazı",
    "Voice" : "Ses",
    "Social network" : "Sosyal ağ",
    "Settings" : "Ayarlar"
},
"nplurals=2; plural=(n > 1);");
